.. _base_ref:

Base
====

The :mod:`aeon.base` module contains abstract base classes.

.. automodule:: aeon.base
    :no-members:
    :no-inherited-members:

Base classes
------------

.. currentmodule:: aeon.base

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    BaseObject
    BaseEstimator
